==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class HardwareSystemVendorFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendorFluent<A>{
  public HardwareSystemVendorFluentImpl() {
  }
  public HardwareSystemVendorFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendor instance) {
    this.withManufacturer(instance.getManufacturer()); 
    this.withProductName(instance.getProductName()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String manufacturer;
  private java.lang.String productName;
  private java.lang.String serialNumber;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getManufacturer() {
    return this.manufacturer;
  }
  public A withManufacturer(java.lang.String manufacturer) {
    this.manufacturer=manufacturer; return (A) this;
  }
  public java.lang.Boolean hasManufacturer() {
    return this.manufacturer != null;
  }
  
  /**
   * Method is deprecated. use withManufacturer instead.
   */
  @java.lang.Deprecated
  public A withNewManufacturer(java.lang.String arg0) {
    return (A)withManufacturer(new String(arg0));
  }
  public java.lang.String getProductName() {
    return this.productName;
  }
  public A withProductName(java.lang.String productName) {
    this.productName=productName; return (A) this;
  }
  public java.lang.Boolean hasProductName() {
    return this.productName != null;
  }
  
  /**
   * Method is deprecated. use withProductName instead.
   */
  @java.lang.Deprecated
  public A withNewProductName(java.lang.String arg0) {
    return (A)withProductName(new String(arg0));
  }
  public java.lang.String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(java.lang.String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public java.lang.Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  /**
   * Method is deprecated. use withSerialNumber instead.
   */
  @java.lang.Deprecated
  public A withNewSerialNumber(java.lang.String arg0) {
    return (A)withSerialNumber(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HardwareSystemVendorFluentImpl that = (HardwareSystemVendorFluentImpl) o;
    if (manufacturer != null ? !manufacturer.equals(that.manufacturer) :that.manufacturer != null) return false;
    if (productName != null ? !productName.equals(that.productName) :that.productName != null) return false;
    if (serialNumber != null ? !serialNumber.equals(that.serialNumber) :that.serialNumber != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(manufacturer,  productName,  serialNumber,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class HardwareSystemVendorFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendorFluent<A>{
  public HardwareSystemVendorFluentImpl() {
  }
  public HardwareSystemVendorFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareSystemVendor instance) {
    this.withManufacturer(instance.getManufacturer()); 
    this.withProductName(instance.getProductName()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String manufacturer;
  private java.lang.String productName;
  private java.lang.String serialNumber;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getManufacturer() {
    return this.manufacturer;
  }
  public A withManufacturer(java.lang.String manufacturer) {
    this.manufacturer=manufacturer; return (A) this;
  }
  public java.lang.Boolean hasManufacturer() {
    return this.manufacturer != null;
  }
  
  /**
   * Method is deprecated. use withManufacturer instead.
   */
  @java.lang.Deprecated
  public A withNewManufacturer(java.lang.String arg0) {
    return (A)withManufacturer(new String(arg0));
  }
  public java.lang.String getProductName() {
    return this.productName;
  }
  public A withProductName(java.lang.String productName) {
    this.productName=productName; return (A) this;
  }
  public java.lang.Boolean hasProductName() {
    return this.productName != null;
  }
  
  /**
   * Method is deprecated. use withProductName instead.
   */
  @java.lang.Deprecated
  public A withNewProductName(java.lang.String arg0) {
    return (A)withProductName(new String(arg0));
  }
  public java.lang.String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(java.lang.String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public java.lang.Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  /**
   * Method is deprecated. use withSerialNumber instead.
   */
  @java.lang.Deprecated
  public A withNewSerialNumber(java.lang.String arg0) {
    return (A)withSerialNumber(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HardwareSystemVendorFluentImpl that = (HardwareSystemVendorFluentImpl) o;
    if (manufacturer != null ? !manufacturer.equals(that.manufacturer) :that.manufacturer != null) return false;
    if (productName != null ? !productName.equals(that.productName) :that.productName != null) return false;
    if (serialNumber != null ? !serialNumber.equals(that.serialNumber) :that.serialNumber != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(manufacturer,  productName,  serialNumber,  additionalProperties,  super.hashCode());
  }
  
}
